@@ -55,6 +55,8 @@ __all__ = ('Event', 'Group', 'Project', 'SearchDocument')
 
 def slugify_instance(inst, label, **kwargs):
     base_slug = slugify(label)
+    if not base_slug:
+        base_slug = 'default_%s' % (uuid.uuid4())
     manager = type(inst).objects
     inst.slug = base_slug
     n = 0
@@ -221,8 +223,8 @@ class Project(Model):
         super(Project, self).save(*args, **kwargs)
 
     def delete(self):
-        # This hadles cascades properly
-        # TODO: this doesnt clean up the index
+        # This handles cascades properly
+        # TODO: this doesn't clean up the index
         for model in (Event, Group, FilterValue, GroupTag, GroupCountByMinute):
             model.objects.filter(project=self).delete()
         super(Project, self).delete()
@@ -723,7 +725,7 @@ class GroupBookmark(Model):
     """
     project = models.ForeignKey(Project, related_name="bookmark_set")  # denormalized
     group = models.ForeignKey(Group, related_name="bookmark_set")
-    # namespace related_name on User since we dont own the model
+    # namespace related_name on User since we don't own the model
     user = models.ForeignKey(User, related_name="sentry_bookmark_set")
 
     objects = BaseManager()
@@ -1005,6 +1007,7 @@ class Activity(Model):
     SET_PUBLIC = 4
     SET_PRIVATE = 5
     SET_REGRESSION = 6
+    CREATE_ISSUE = 7
 
     TYPE = (
         # (TYPE, verb-slug)
@@ -1015,6 +1018,7 @@ class Activity(Model):
         (SET_PUBLIC, 'set_public'),
         (SET_PRIVATE, 'set_private'),
         (SET_REGRESSION, 'set_regression'),
+        (CREATE_ISSUE, 'create_issue'),
     )
 
     project = models.ForeignKey(Project)
