@@ -36,24 +36,37 @@ def init_all_applications():
 init_all_applications()
 
 urlpatterns = patterns('',
-    url(r'^_static/(?P<module>[^/]+)/(?P<path>.*)$', generic.static_media, name='sentry-media'),
+    url(r'^_static/(?P<module>[^/]+)/(?P<path>.*)$', generic.static_media,
+        name='sentry-media'),
 
     # Account
-    url(r'^login/$', accounts.login, name='sentry-login'),
-    url(r'^login-redirect/$', accounts.login_redirect, name='sentry-login-redirect'),
-    url(r'^logout/$', accounts.logout, name='sentry-logout'),
-    url(r'^register/$', accounts.register, name='sentry-register'),
-    url(r'^account/recover/$', accounts.recover, name='sentry-account-recover'),
-    url(r'^account/recover/confirm/(?P<user_id>[\d]+)/(?P<hash>[0-9a-zA-Z]+)/$', accounts.recover_confirm, name='sentry-account-recover-confirm'),
-    url(r'^account/settings/$', accounts.settings, name='sentry-account-settings'),
-    url(r'^account/settings/appearance/$', accounts.appearance_settings, name='sentry-account-settings-appearance'),
-    url(r'^account/settings/identities/$', accounts.list_identities, name='sentry-account-settings-identities'),
-    url(r'^account/settings/notifications/$', accounts.notification_settings, name='sentry-account-settings-notifications'),
+    url(r'^login/$', accounts.login,
+        name='sentry-login'),
+    url(r'^login-redirect/$', accounts.login_redirect,
+        name='sentry-login-redirect'),
+    url(r'^logout/$', accounts.logout,
+        name='sentry-logout'),
+    url(r'^register/$', accounts.register,
+        name='sentry-register'),
+    url(r'^account/recover/$', accounts.recover,
+        name='sentry-account-recover'),
+    url(r'^account/recover/confirm/(?P<user_id>[\d]+)/(?P<hash>[0-9a-zA-Z]+)/$', accounts.recover_confirm,
+        name='sentry-account-recover-confirm'),
+    url(r'^account/settings/$', accounts.settings,
+        name='sentry-account-settings'),
+    url(r'^account/settings/appearance/$', accounts.appearance_settings,
+        name='sentry-account-settings-appearance'),
+    url(r'^account/settings/identities/$', accounts.list_identities,
+        name='sentry-account-settings-identities'),
+    url(r'^account/settings/notifications/$', accounts.notification_settings,
+        name='sentry-account-settings-notifications'),
     url(r'^account/settings/social/', include('social_auth.urls')),
 
     # Settings - Teams
-    url(r'^account/teams/$', teams.team_list, name='sentry-team-list'),
-    url(r'^account/teams/new/$', teams.create_new_team, name='sentry-new-team'),
+    url(r'^account/teams/$', teams.team_list,
+        name='sentry-team-list'),
+    url(r'^account/teams/new/$', teams.create_new_team,
+        name='sentry-new-team'),
     url(r'^account/teams/(?P<team_slug>[\w_-]+)/settings/$', teams.manage_team,
         name='sentry-manage-team'),
     url(r'^account/teams/(?P<team_slug>[\w_-]+)/remove/$', teams.remove_team,
@@ -98,7 +111,8 @@ urlpatterns = patterns('',
         name='sentry-accept-invite'),
 
     # Settings - Projects
-    url(r'^account/teams/(?P<team_slug>[\w_-]+)/projects/new/$', projects.new_project, name='sentry-new-project'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/projects/new/$', projects.new_project,
+        name='sentry-new-project'),
 
     url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/settings/$', projects.manage_project,
         name='sentry-manage-project'),
@@ -130,42 +144,68 @@ urlpatterns = patterns('',
         name='sentry-project-notifications'),
 
     # Generic
-    url(r'^$', generic.dashboard, name='sentry'),
-    url(r'^wall/$', generic.wall_display, name='sentry-wall'),
+    url(r'^$', generic.dashboard,
+        name='sentry'),
+    url(r'^wall/$', generic.wall_display,
+        name='sentry-wall'),
 
     # Admin
-    url(r'^manage/status/$', admin.status_env, name='sentry-admin-status'),
-    url(r'^manage/status/packages/$', admin.status_packages, name='sentry-admin-packages-status'),
-    url(r'^manage/status/mail/$', admin.status_mail, name='sentry-admin-mail-status'),
-    url(r'^manage/stats/$', admin.stats, name='sentry-admin-stats'),
+    url(r'^manage/status/$', admin.status_env,
+        name='sentry-admin-status'),
+    url(r'^manage/status/packages/$', admin.status_packages,
+        name='sentry-admin-packages-status'),
+    url(r'^manage/status/mail/$', admin.status_mail,
+        name='sentry-admin-mail-status'),
+    url(r'^manage/stats/$', admin.stats,
+        name='sentry-admin-stats'),
+
+    # Admin - Teams
+    url(r'^manage/teams/$', admin.manage_teams,
+        name='sentry-admin-teams'),
 
     # Admin - Projects
-    url(r'^manage/projects/$', admin.manage_projects, name='sentry-admin-projects'),
+    url(r'^manage/projects/$', admin.manage_projects,
+        name='sentry-admin-projects'),
 
     # Admin - Users
-    url(r'^manage/users/$', admin.manage_users, name='sentry-admin-users'),
-    url(r'^manage/users/new/$', admin.create_new_user, name='sentry-admin-new-user'),
-    url(r'^manage/users/(?P<user_id>\d+)/$', admin.edit_user, name='sentry-admin-edit-user'),
-    url(r'^manage/users/(?P<user_id>\d+)/remove/$', admin.remove_user, name='sentry-admin-remove-user'),
-    url(r'^manage/users/(?P<user_id>\d+)/projects/$', admin.list_user_projects, name='sentry-admin-list-user-projects'),
+    url(r'^manage/users/$', admin.manage_users,
+        name='sentry-admin-users'),
+    url(r'^manage/users/new/$', admin.create_new_user,
+        name='sentry-admin-new-user'),
+    url(r'^manage/users/(?P<user_id>\d+)/$', admin.edit_user,
+        name='sentry-admin-edit-user'),
+    url(r'^manage/users/(?P<user_id>\d+)/remove/$', admin.remove_user,
+        name='sentry-admin-remove-user'),
+    url(r'^manage/users/(?P<user_id>\d+)/projects/$', admin.list_user_projects,
+        name='sentry-admin-list-user-projects'),
 
     # Admin - Plugins
-    url(r'^manage/plugins/(?P<slug>[\w_-]+)/$', admin.configure_plugin, name='sentry-admin-configure-plugin'),
+    url(r'^manage/plugins/(?P<slug>[\w_-]+)/$', admin.configure_plugin,
+        name='sentry-admin-configure-plugin'),
 
     # API / JS
-    url(r'^crossdomain\.xml$', api.crossdomain_xml_index, name='sentry-api-crossdomain-xml-index'),
-    url(r'^api/store/$', api.StoreView.as_view(), name='sentry-api-store'),
+    url(r'^crossdomain\.xml$', api.crossdomain_xml_index,
+        name='sentry-api-crossdomain-xml-index'),
+    url(r'^api/store/$', api.StoreView.as_view(),
+        name='sentry-api-store'),
 
     # Client API endpoints. MUST NOT BE CHANGED
-    url(r'^api/(?P<project_id>[\w_-]+)/crossdomain\.xml$', api.crossdomain_xml, name='sentry-api-crossdomain-xml'),
-    url(r'^api/(?P<project_id>[\w_-]+)/store/$', api.StoreView.as_view(), name='sentry-api-store'),
+    url(r'^api/(?P<project_id>[\w_-]+)/crossdomain\.xml$', api.crossdomain_xml,
+        name='sentry-api-crossdomain-xml'),
+    url(r'^api/(?P<project_id>[\w_-]+)/store/$', api.StoreView.as_view(),
+        name='sentry-api-store'),
 
     # Generic API
-    url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/poll/$', api.poll, name='sentry-api-poll'),
-    url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/resolve/$', api.resolve, name='sentry-api-resolve'),
-    url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/bookmark/$', api.bookmark, name='sentry-api-bookmark'),
-    url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/clear/$', api.clear, name='sentry-api-clear'),
-    url(r'^api/(?P<team_slug>[\w_-]+)/(?:(?P<project_id>[\w_-]+)/)?chart/$', api.chart, name='sentry-api-chart'),
+    url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/poll/$', api.poll,
+        name='sentry-api-poll'),
+    url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/resolve/$', api.resolve,
+        name='sentry-api-resolve'),
+    url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/bookmark/$', api.bookmark,
+        name='sentry-api-bookmark'),
+    url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/clear/$', api.clear,
+        name='sentry-api-clear'),
+    url(r'^api/(?P<team_slug>[\w_-]+)/(?:(?P<project_id>[\w_-]+)/)?chart/$', api.chart,
+        name='sentry-api-chart'),
     url(r'^api/(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>[\w_-]+)/remove/$', api.remove_group,
         name='sentry-api-remove-group'),
 
@@ -195,31 +235,48 @@ urlpatterns = patterns('',
         name='sentry-api-search-projects'),
 
     # Users
-    url(r'^(?P<team_slug>[\w_-]+)/users/$', users.user_list, name='sentry-users'),
-    url(r'^(?P<team_slug>[\w_-]+)/users/(?P<user_id>\d+)/$', users.user_details, name='sentry-user-details'),
+    url(r'^(?P<team_slug>[\w_-]+)/users/$', users.user_list,
+        name='sentry-users'),
+    url(r'^(?P<team_slug>[\w_-]+)/users/(?P<user_id>\d+)/$', users.user_details,
+        name='sentry-user-details'),
 
     # Project specific
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/get-started/$', projects.get_started, name='sentry-get-started'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/$', groups.group, name='sentry-group'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/$', groups.group_event_list, name='sentry-group-events'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/json/$', groups.group_event_list_json, name='sentry-group-events-json'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/(?P<event_id>\d+)/$', groups.group_event_details, name='sentry-group-event'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/(?P<event_id_or_latest>(\d+|latest))/json/$', groups.group_event_details_json, name='sentry-group-event-json'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/actions/(?P<slug>[\w_-]+)/', groups.group_plugin_action, name='sentry-group-plugin-action'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/tags/$', groups.group_tag_list, name='sentry-group-tags'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/tags/(?P<tag_name>[^/]+)/$', groups.group_tag_details, name='sentry-group-tag-details'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/events/$', events.event_list, name='sentry-events'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/events/(?P<event_id>\d+)/replay/$', events.replay_event, name='sentry-replay'),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/search/$', groups.search, name='sentry-search'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/get-started/$', projects.get_started,
+        name='sentry-get-started'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/$', groups.group,
+        name='sentry-group'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/$', groups.group_event_list,
+        name='sentry-group-events'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/json/$', groups.group_event_list_json,
+        name='sentry-group-events-json'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/(?P<event_id>\d+)/$', groups.group_event_details,
+        name='sentry-group-event'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/events/(?P<event_id_or_latest>(\d+|latest))/json/$', groups.group_event_details_json,
+        name='sentry-group-event-json'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/actions/(?P<slug>[\w_-]+)/', groups.group_plugin_action,
+        name='sentry-group-plugin-action'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/tags/$', groups.group_tag_list,
+        name='sentry-group-tags'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/tags/(?P<tag_name>[^/]+)/$', groups.group_tag_details,
+        name='sentry-group-tag-details'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/events/$', events.event_list,
+        name='sentry-events'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/events/(?P<event_id>\d+)/replay/$', events.replay_event,
+        name='sentry-replay'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/search/$', groups.search,
+        name='sentry-search'),
     url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/alerts/$', alerts.alert_list,
         name='sentry-project-alerts'),
     url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/alerts/(?P<alert_id>\d+)/$', alerts.alert_details,
         name='sentry-project-alert-details'),
     url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/stream/$', groups.group_list),
-    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/$', groups.group_list, name='sentry-stream'),
+    url(r'^(?P<team_slug>[\w_-]+)/(?P<project_id>[\w_-]+)/$', groups.group_list,
+        name='sentry-stream'),
 
-    url(r'^(?P<team_slug>[\w_-]+)/$', groups.dashboard, name='sentry'),
+    url(r'^(?P<team_slug>[\w_-]+)/$', groups.dashboard,
+        name='sentry'),
 
     # Legacy
-    url(r'^(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/$', groups.redirect_to_group, name='sentry-group'),
+    url(r'^(?P<project_id>[\w_-]+)/group/(?P<group_id>\d+)/$', groups.redirect_to_group,
+        name='sentry-group'),
 )
